==> zio-aws-macie2_2.13-5.17.295.11-sources.jar: zio/aws/macie2/model/ListFindingsFiltersResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListFindingsFiltersResponse(
    findingsFilterListItems: Optional[
      Iterable[zio.aws.macie2.model.FindingsFilterListItem]
    ] = Optional.Absent,
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse = {
    import ListFindingsFiltersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
      .builder()
      .optionallyWith(
        findingsFilterListItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.findingsFilterListItems)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly =
    zio.aws.macie2.model.ListFindingsFiltersResponse.wrap(buildAwsValue())
}
object ListFindingsFiltersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListFindingsFiltersResponse =
      zio.aws.macie2.model.ListFindingsFiltersResponse(
        findingsFilterListItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def findingsFilterListItems
        : Optional[List[zio.aws.macie2.model.FindingsFilterListItem.ReadOnly]]
    def nextToken: Optional[__string]
    def getFindingsFilterListItems: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.FindingsFilterListItem.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "findingsFilterListItems",
      findingsFilterListItems
    )
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ) extends zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly {
    override val findingsFilterListItems
        : Optional[List[zio.aws.macie2.model.FindingsFilterListItem.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.findingsFilterListItems())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.FindingsFilterListItem.wrap(item)
          }.toList
        )
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ): zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_3-5.17.116.1-sources.jar: zio/aws/macie2/model/ListFindingsFiltersResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ListFindingsFiltersResponse(
    findingsFilterListItems: Option[
      Iterable[zio.aws.macie2.model.FindingsFilterListItem]
    ] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse = {
    import ListFindingsFiltersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
      .builder()
      .optionallyWith(
        findingsFilterListItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.findingsFilterListItems)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly =
    zio.aws.macie2.model.ListFindingsFiltersResponse.wrap(buildAwsValue())
}
object ListFindingsFiltersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListFindingsFiltersResponse =
      zio.aws.macie2.model.ListFindingsFiltersResponse(
        findingsFilterListItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def findingsFilterListItems
        : Option[List[zio.aws.macie2.model.FindingsFilterListItem.ReadOnly]]
    def nextToken: Option[__string]
    def getFindingsFilterListItems: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.FindingsFilterListItem.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "findingsFilterListItems",
      findingsFilterListItems
    )
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ) extends zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly {
    override val findingsFilterListItems
        : Option[List[zio.aws.macie2.model.FindingsFilterListItem.ReadOnly]] =
      scala
        .Option(impl.findingsFilterListItems())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.macie2.model.FindingsFilterListItem.wrap(item)
          }.toList
        )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListFindingsFiltersResponse
  ): zio.aws.macie2.model.ListFindingsFiltersResponse.ReadOnly = new Wrapper(
    impl
  )
}
